Class AbstractPropertyReferenceManager
java.lang.Object
io.micronaut.serde.reference.AbstractPropertyReferenceManager
- All Implemented Interfaces:
PropertyReferenceManager
public abstract class AbstractPropertyReferenceManager
extends Object
implements PropertyReferenceManager
Abstract implementation of
PropertyReferenceManager.- Since:
- 1.0.0
-
Nested Class Summary
Nested classes/interfaces inherited from interface PropertyReferenceManager
PropertyReferenceManager.ReferenceScope -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected @Nullable ArrayDeque<PropertyReference<?, ?>> used to store current references. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionOpens a scope that releases the managed references pushed into it when closed.voidRemove the last parent (if present) from the stack.<B,P> void pushManagedRef(PropertyReference<B, P> reference) Pushes a parent onto the stack.
-
Field Details
-
refs
used to store current references.
-
-
Constructor Details
-
AbstractPropertyReferenceManager
public AbstractPropertyReferenceManager()
-
-
Method Details
-
openReferenceScope
Description copied from interface:PropertyReferenceManagerOpens a scope that releases the managed references pushed into it when closed.- Specified by:
openReferenceScopein interfacePropertyReferenceManager- Returns:
- The reference scope
-
pushManagedRef
Description copied from interface:PropertyReferenceManagerPushes a parent onto the stack.- Specified by:
pushManagedRefin interfacePropertyReferenceManager- Type Parameters:
B- The bean typeP- The parent- Parameters:
reference- The reference- See Also:
-
popManagedRef
public void popManagedRef()Description copied from interface:PropertyReferenceManagerRemove the last parent (if present) from the stack.- Specified by:
popManagedRefin interfacePropertyReferenceManager- See Also:
-