Interface PropertyReferenceManager
- All Known Subinterfaces:
Deserializer.DecoderContext, Serializer.EncoderContext
- All Known Implementing Classes:
AbstractPropertyReferenceManager
@Internal
public interface PropertyReferenceManager
interface for managing property references.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceA managed-reference scope. -
Method Summary
Modifier and TypeMethodDescriptionOpens a scope that releases the managed references pushed into it when closed.voidRemove the last parent (if present) from the stack.<B,P> void pushManagedRef(PropertyReference<B, P> reference) Pushes a parent onto the stack.
-
Method Details
-
openReferenceScope
Opens a scope that releases the managed references pushed into it when closed.- Returns:
- The reference scope
- Since:
- 3.2
-
pushManagedRef
Pushes a parent onto the stack.- Type Parameters:
B- The bean typeP- The parent- Parameters:
reference- The reference- See Also:
-
popManagedRef
void popManagedRef()Remove the last parent (if present) from the stack.- See Also:
-